require("print_r")

core.register_converters("debug", function(data, name)
	print_r(name .. ": <" .. data .. ">")
	return data
end)

--
-- Sample 1
--

-- This register new sample-fetch called "lua.sample1"
core.register_fetches("sample1", function(txn)

	-- By default, all varibles are global. specify the local
	-- keyword to avoid bug.aThe following line store the
	-- content of the sample-fetch "path" in the variable
	-- "path".
	local path = txn.f:path()

	-- Print out the content of path variable. The data
	-- id display on the HAProxy standard output.
	print_r(path)

	-- Return the value of the path as the sample-fetch
	-- result.
	return path
end)

--
-- Sample 2
--

-- This function returns all condition in an array.
function get_variables(txn)

	-- This array will contains conditions
	local cond = {}

	-- True if the path starts with "/payment/"
	cond['is_payment_page'] = string.match(txn.sf:path(), '^/payment/') ~= nil

	-- True if the front connection is SSL
	cond['is_ssl'] = txn.f:ssl_fc() == 1

	-- True if the domain name asked is preprod
	cond['is_preprod'] = txn.f:req_fhdr('host') == 'preprod.test.com'

	-- True if the cookie 'DEBUG' is set
	cond['is_cookie_exception'] = txn.f:req_cook_cnt('DEBUG') >= 1

	-- Display extracted conditions
--	print_r(cond)
	return cond
end

-- This sample fetch return 1 if we need HTTPS redirect
core.register_fetches("sample2_1", function(txn)

	-- Get input conditions
	local cond = get_variables(txn)

	-- Return result according with conditions value and policy.
	if cond['is_ssl']              then return 0 end
	if cond['is_cookie_exception'] then return 0 end
	if cond['is_preprod']          then return 0 end
	if cond['is_payment_page']     then return 1 end
	return 0
end)

-- This sample fetch returns 1 if we need HTTP redirect
core.register_fetches("sample2_2", function(txn)

	-- Get input conditions
	local cond = get_variables(txn)

	-- Return result according with conditions value and policy.
	if not cond['is_ssl']          then return 0 end
	if cond['is_cookie_exception'] then return 1 end
	if cond['is_preprod']          then return 1 end
	if not cond['is_payment_page'] then return 1 end
	return 0
end)
